==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ProfileEnrollmentPolicyRuleActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ProfileEnrollmentPolicyRuleAction;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ProfileEnrollmentPolicyRuleActions
 */
@JsonPropertyOrder({ ProfileEnrollmentPolicyRuleActions.JSON_PROPERTY_PROFILE_ENROLLMENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ProfileEnrollmentPolicyRuleActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PROFILE_ENROLLMENT = "profileEnrollment";
    private ProfileEnrollmentPolicyRuleAction profileEnrollment;

    public ProfileEnrollmentPolicyRuleActions() {
    }

    public ProfileEnrollmentPolicyRuleActions profileEnrollment(ProfileEnrollmentPolicyRuleAction profileEnrollment) {

        this.profileEnrollment = profileEnrollment;
        return this;
    }

    /**
     * Get profileEnrollment
     *
     * @return profileEnrollment
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ProfileEnrollmentPolicyRuleAction getProfileEnrollment() {
        return profileEnrollment;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfileEnrollment(ProfileEnrollmentPolicyRuleAction profileEnrollment) {
        this.profileEnrollment = profileEnrollment;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRuleActions profileEnrollmentPolicyRuleActions = (ProfileEnrollmentPolicyRuleActions) o;
        return Objects.equals(this.profileEnrollment, profileEnrollmentPolicyRuleActions.profileEnrollment);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(profileEnrollment);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRuleActions {\n");
        sb.append("    profileEnrollment: ").append(toIndentedString(profileEnrollment)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ProfileEnrollmentPolicyRuleActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ProfileEnrollmentPolicyRuleAction;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ProfileEnrollmentPolicyRuleActions
 */
@JsonPropertyOrder({ ProfileEnrollmentPolicyRuleActions.JSON_PROPERTY_PROFILE_ENROLLMENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ProfileEnrollmentPolicyRuleActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PROFILE_ENROLLMENT = "profileEnrollment";
    private ProfileEnrollmentPolicyRuleAction profileEnrollment;

    public ProfileEnrollmentPolicyRuleActions() {
    }

    public ProfileEnrollmentPolicyRuleActions profileEnrollment(ProfileEnrollmentPolicyRuleAction profileEnrollment) {

        this.profileEnrollment = profileEnrollment;
        return this;
    }

    /**
     * Get profileEnrollment
     *
     * @return profileEnrollment
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ProfileEnrollmentPolicyRuleAction getProfileEnrollment() {
        return profileEnrollment;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE_ENROLLMENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfileEnrollment(ProfileEnrollmentPolicyRuleAction profileEnrollment) {
        this.profileEnrollment = profileEnrollment;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRuleActions profileEnrollmentPolicyRuleActions = (ProfileEnrollmentPolicyRuleActions) o;
        return Objects.equals(this.profileEnrollment, profileEnrollmentPolicyRuleActions.profileEnrollment);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(profileEnrollment);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRuleActions {\n");
        sb.append("    profileEnrollment: ").append(toIndentedString(profileEnrollment)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
